""" Gromit Dependancy Handling Code

Dependancies are really why gromit exists - so that you can use one config
file on all the clients, and a different config file on all the servers.

Or maybe you want/need one service turned on/off on RH 6.2, and a different
one on 7.1.

"""

import string

import deps
import rules


def CheckDependancies(pkg_dep, release, keywords):
    """ Dependancy checks for various functions"""
    
    if pkg_dep != "" and \
       not rules.gromit_config["backend"].is_pkg_installed(pkg_dep):
        #dbg_print("we can skip due to %s" % pkg_dep)
        return 0
        
    if release != "" and release != rules.gromit_config["release"]:
        #dbg_print("requested release %s does not match current relase %s"
        #            % (release, rules.gromit_config["release"]))
        return 0
        
    if keywords != "" and \
       not deps.CheckKeywordsDependancy(rules.gromit_config["host_keywords"], 
                                ParseKeywordsDeps(keywords)):
        #dbg_print("requested keywords %s does not match current keywords %s"
        #           % (keywords, rules.gromit_config["host_keywords"]))
        return 0
    
    return 1


def ParseKeywordsDeps(keywords_string):
    # input should be "workstation +laptop -server -dual-boot"
    # output should be { "workstation" = 1,
    #                    "laptop" = 1,
    #                    "server" = 0,
    #                    "dual-boot" = 0 }

    dep_keywords = {}
    klist = string.split(keywords_string, " ")

    for spec in klist:
        if len(spec) == 0:
            continue
        elif spec[0] == "+":
            dep_keywords[spec[1:]] = 1
        elif spec[0] == "-":
            dep_keywords[spec[1:]] = 0
        else:
            dep_keywords[spec] = 1
                                             
    return dep_keywords
    
    
def CheckKeywordsDependancy(host_keywords, dep_keywords):
    assert type(host_keywords) == type({})  
    assert type(dep_keywords) == type({})

    for key in dep_keywords.keys():
        # if the dep_keywords is true/1, the host MUST have that key AND
        #   it MUST be true
        if dep_keywords[key] == 1:
            if not host_keywords.has_key(key) or host_keywords[key] != 1:
                return 0

        # if the dep_keywords is false/0, the host MUST either not have that
        # key, OR the key MUST be false/0.
        if dep_keywords[key] == 0:
            if host_keywords.has_key(key) and host_keywords[key] == 1:
                return 0
        
    # default result is true
    return 1
           
                            
## END OF LINE ##
    
