""" Sun Solaris Backend

I hadn't originally intended to finish out the solaris module, but here is 
one that works in a minimum sort of way. The chances of people having built
pkg type packages for everything are virtually nil, so I cheated a little
and on solaris the "pkg" nomenclature is just a file to look for.

That means that right now, it would be "hard" to "impossible" to share the
same rules file between solaris and redhat type hosts. That was not a goal
of gromit, so I'm not too upset by it, but if anyone can suggest non-kludgey
solutions, I'm taking patches...

See redhat.py for a fully implemented backend.

See backend.py for documentation for all the API calls.
   
"""

import os
import os.path
import string


def HostMatch():
    # This particular file was recommended by Karsten.
    if os.path.isfile("/etc/default/inetinit"):
        return 1
    else:
        return 0


class Backend:
    """ For proper documentation, see the base module backend.py. """

    def __init__(self):
        # get the arch and release
        f = os.popen("/bin/uname -r -p", "r")
        tmp = string.strip(f.readline())
        self._release, self._arch = string.split(tmp, " ")
        f.close()
        
        
    def __del__(self):
        pass
        
        
    def get_os_release(self):
        return self._release


    def get_host_arch(self):
        return self._arch   
        
        
    def is_pkg_installed(self, pkg):
        # Solaris may be the greatest thing since TCP/IP, but its package
        # management "system" is a complete circus. 
        # I have therefore punted from the 10 yard line and treat "pkg" 
        # as a file to search for - if the file is found, then the pkg
        # is "installed".
        
        if os.path.exists(pkg):
            return 1
        else:
            return 0


    def service_control(self, service, action):
        # start stop restart condrestart status reload panic save 
        # start and stop to begin with, add reload/restart later

        if action != "start" and action != "stop":
            sys.stderr.write("ERROR: service_control() action must be " +
                             "either 'start' or 'stop'\n")
            return

        # according to one of the solaris admins here, there's no way to
        # tell at run-time whether service X is up or down.

        # as a result, this might be quite dangerous.
        if os.system("/etc/init.d/%s %s > /dev/null 2>&1" % 
                     (service, action)):
            sys.stderr.write("ERROR: /sbin/service on %s returned an " +
                             "error of %s\n")
            return


    def service_config(self, service, action):
        # --add --del, --level, on/off/reset
        # on/off to begin with, --level later

        # what needs to happen here is direct symlink manipulatin in 
        # /etc/rc?.d. Not by me, however.
        pass

 
## END OF LINE ##
